BaseConfiguration class abstract

Base configuration that will be passed from tests to the application

Constructors

BaseConfiguration()

Properties

hashCode → int
The hash code for this object.
no setterinherited
platform → TestPlatform?
Describes what platform's UI should be rendered in the application. This value is passed via fastdriver command using --platform option. This value should be handled on the application side - fastdriver just passes it.
no setter
resolution → Resolution
Describes what size should be the application window on Desktop. This value is passed via fastdriver command using --resolution option. This is ignored on mobile.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes BaseConfiguration to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited