TestProperties class

Properties that are passed to the tests from command line

Constructors

TestProperties(List<String> args)

Properties

additionalArgs → String
Additional parameters passed via --test-args from fastdriver. This is used to extend the capabilities of your tests without the need of modifying fastdriver's code.
no setter
arguments → ArgResults
Parsed representation of the arguments that can be extended to your liking
final
hashCode → int
The hash code for this object.
no setterinherited
locale → String
Current locale/locale passed from fastdriver via --language. This property can be used in tests to set appropriate application language
no setter
platform → TestPlatform?
Describes what platform's UI should be rendered in the application. This value is passed via fastdriver command using --platform option. This value should be handled on the application side - fastdriver just passes it.
no setter
resolution → Resolution
Describes what size should be the application window on Desktop. This value is passed via fastdriver command using --resolution option. This is ignored on mobile.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshotsEnabled → bool
Flag passed via command line (with --screenshots) if the tests should make screenshots. Screenshots are not handled by fastdriver. Developer is responsible for making screenshot when this flag is passed
no setter
vmUrl → String
Current dart VM address used by FlutterDriver to connect to the app
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited